@@ -7,7 +7,7 @@ use diagnostics;
 use mro 'c3';
 use English qw(-no_match_vars);
 use Carp;
-our $VERSION = 4.7;
+our $VERSION = 4.8;
 use Fatal qw( close );
 use Array::Contains;
 #---AUTOPRAGMAEND---
@@ -16,7 +16,7 @@ use Array::Contains;
 # Developed under Artistic license
 
 print "Searching files...\n";
-my @files = (find_pm('lib'), find_pm('devscripts'));
+my @files = (find_pm('lib'), find_pm('devscripts'), find_pm('example'));
 
 print "Changing files:\n";
 foreach my $file (@files) {
@@ -33,7 +33,7 @@ foreach my $file (@files) {
 
     open(my $ofh, ">", $file) or die($ERRNO);
     foreach my $line (@lines) {
-        $line =~ s/\(C\)\ \d\d\d\d-\d\d\d\d\ Rene\ Schickbauer/\(C\) 2008-2017 Rene Schickbauer/ig;
+        $line =~ s/\(C\)\ \d\d\d\d-\d\d\d\d\ Rene\ Schickbauer/\(C\) 2008-2018 Rene Schickbauer/ig;
         print $ofh $line;
     }
     close $ofh;
