@@ -7,12 +7,12 @@ use diagnostics;
 use mro 'c3';
 use English qw(-no_match_vars);
 use Carp;
-our $VERSION = 4.7;
+our $VERSION = 4.8;
 use Fatal qw( close );
 use Array::Contains;
 #---AUTOPRAGMAEND---
 
-# MAPLAT  (C) 2008-2017 Rene Schickbauer
+# MAPLAT  (C) 2008-2018 Rene Schickbauer
 # Developed under Artistic license
 
 my $newversion = shift @ARGV || "???";
@@ -23,7 +23,7 @@ if($newversion eq "???") {
 }
 
 print "Searching files...\n";
-my @files = (find_pm('lib'), find_pm('devscripts'));
+my @files = (find_pm('lib'), find_pm('devscripts'), find_pm('example'));
 
 print "Changing files:\n";
 foreach my $file (@files) {
