@@ -7,7 +7,7 @@ use diagnostics;
 use mro 'c3';
 use English;
 use Carp;
-our $VERSION = 4.1;
+our $VERSION = 4.8;
 use Fatal qw( close );
 use Array::Contains;
 #---AUTOPRAGMAEND---
@@ -19,7 +19,7 @@ use Data::Dumper;
 
 my $username = 'exampleuser';
 my $password = 'unsafepassword';
-my $applicationname = 'chatclient';
+my $applicationname = 'clock';
 my $is_caching = 0;
 
 my $chat = Net::Clacks::Client->new('127.0.0.1', 18888, $username, $password, $applicationname, $is_caching);
@@ -28,17 +28,12 @@ my $clockname = 'example::notify';
 
 my $last = '';
 
-my $nextping = 0;
-
 while(1) {
     my $now = getCurrentMinute();
     if($now ne $last) {
         $chat->notify($clockname);
-        $last = $now;
-    }
-    if($nextping < time) {
         $chat->ping();
-        $nextping = time + 60;
+        $last = $now;
     }
 
     $chat->doNetwork();
